Struct custom_print::IoTryWriter [−][src]
pub struct IoTryWriter<F1, F2>(_, _);
A writer that uses write_bytes and has both write and flush methods.
It calls write_bytes for each formatted chunk like the FmtTryWriter,
but provides write and flush methods that allows you to use BufWriter, LineWriter etc.
Write function can return either (), usize, io::Result<()>, io::Result<usize>,
Result<(), ffi::NulError> or Result<usize, ffi::NulError>.
The usize itself or in Result indicates how many bytes were written.
write_fmt method that is used by write! and writeln!
will continuously call write until there is no more data to be written
or a non-ErrorKind::Interrupted kind is returned.
Flush function can return either () or io::Result<()>.
Writer propagates error to the caller if the write function returns Result::Err.
Implementations
Creates a new IoTryWriter from an object that implements WriteBytes
and object that implements Flush.
Creates a new IoTryWriter with a WriteBytes wrapper
deduced with IntoTryWriteFn by the closure signature and constructed from it.
Writes a formatted string into this writer, returning any error encountered.
This method is primarily used to interface with the format_args! macro,
but it is rare that this should explicitly be called.
The write! macro should be favored to invoke this method instead.