Struct custom_print::IoWriter [−][src]
pub struct IoWriter<F1, F2>(_, _);
A writer that uses write_bytes and has both write and flush methods.
It calls write_bytes for each formatted chunk like the FmtWriter,
but provides write and flush methods that allows you to use BufWriter, LineWriter etc.
Write function can return either
(), usize, for<E> Result<(), E> or for<E> Result<usize, E>.
The usize itself or in Result indicates how many bytes were written.
write_fmt method that is used by write! and writeln!
will continuously call write until there is no more data to be written
or a non-ErrorKind::Interrupted kind is returned.
Flush function can return either () or [for<E> Result<(), E>].
Panics
Writer panics if the write function returns Result::Err.
Implementations
Creates a new IoWriter from an object that implements WriteBytes
and object that implements Flush.
Creates a new IoWriter with a WriteBytes wrapper
deduced with IntoWriteFn by the closure signature and constructed from it.
Writes a formatted string into this writer.
This method is primarily used to interface with the format_args! macro,
but it is rare that this should explicitly be called.
The write! macro should be favored to invoke this method instead.